@@ -11,22 +11,17 @@ use strict;
 use warnings;
 
 package Dist::Metadata;
-{
-  $Dist::Metadata::VERSION = '0.925';
-}
-# git description: v0.924-1-g6701fe0
+# git description: v0.925-17-g08a6891
 
-BEGIN {
-  $Dist::Metadata::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Information about a perl module distribution
-
+$Dist::Metadata::VERSION = '0.926';
 use Carp qw(croak carp);
 use CPAN::Meta 2.1 ();
 use List::Util qw(first);    # core in perl v5.7.3
 
 # something that is obviously not a real value
-use constant UNKNOWN => '- unknown -';
+sub UNKNOWN () { '- unknown -' } # constant
 
 
 sub new {
@@ -95,8 +90,14 @@ sub default_metadata {
 
     # optional
     no_index => {
-      # ignore test and build directories by default
-      directory => [qw( inc t xt )],
+      # Ignore the same directories as PAUSE (https://github.com/andk/pause/blob/master/lib/PAUSE/dist.pm#L758):
+        # skip "t" - libraries in ./t are test libraries!
+        # skip "xt" - libraries in ./xt are author test libraries!
+        # skip "inc" - libraries in ./inc are usually install libraries
+        # skip "local" - somebody shipped his carton setup!
+        # skip 'perl5" - somebody shipped her local::lib!
+        # skip 'fatlib' - somebody shipped their fatpack lib!
+      directory => [qw( inc t xt local perl5 fatlib )],
     },
     # provides => { package => { file => $file, version => $version } }
   };
@@ -198,7 +199,7 @@ sub load_meta {
   }
 
   {
-    # always inlude (never index) the default no_index dirs
+    # always include (never index) the default no_index dirs
     my $dir = ($meta->{no_index} ||= {})->{directory} ||= [];
     my %seen = map { ($_ => 1) } @$dir;
     unshift @$dir,
@@ -285,11 +286,12 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
-cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc
-mailto metadata placeholders metacpan
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X cpan testmatrix url
+annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan
 
 =head1 NAME
 
@@ -297,7 +299,7 @@ Dist::Metadata - Information about a perl module distribution
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
@@ -456,7 +458,7 @@ Returns the L<CPAN::Meta> instance in use.
 
   $meta = $dm->meta_from_struct(\%struct);
 
-Passes the the provided C<\%struct> to L<CPAN::Meta/create>
+Passes the provided C<\%struct> to L<CPAN::Meta/create>
 and returns the result.
 
 =head2 package_versions
@@ -531,6 +533,7 @@ X<version> version
 =back
 
 =for Pod::Coverage name version provides
+UNKNOWN
 
 =for test_synopsis my $path_to_archive;
 
@@ -619,58 +622,18 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/Dist-Metadata>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Metadata>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Dist-Metadata>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/D/Dist-Metadata>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Dist-Metadata>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=Dist::Metadata>
+L<http://metacpan.org/release/Dist-Metadata>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-dist-metadata at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Metadata>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Metadata>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -684,6 +647,26 @@ L<https://github.com/rwstauner/Dist-Metadata>
 
 Randy Stauner <rwstauner@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords David Steinbrunner Jeffrey Ryan Thalhammer Sawyer X
+
+=over 4
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+
+=item *
+
+Sawyer X <xsawyerx@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Randy Stauner.
