@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Archive;
-{
-  $Dist::Metadata::Archive::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Archive::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Base class for Dist::Metadata archive files
-
+$Dist::Metadata::Archive::VERSION = '0.926';
 use Carp (); # core
 use parent 'Dist::Metadata::Dist';
 
@@ -84,9 +79,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -94,7 +90,7 @@ Dist::Metadata::Archive - Base class for Dist::Metadata archive files
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
