@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Dir;
-{
-  $Dist::Metadata::Dir::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Dir::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Enable Dist::Metadata for a directory
-
+$Dist::Metadata::Dir::VERSION = '0.926';
 use Carp qw(croak carp);    # core
 use File::Find ();          # core
 use Path::Class 0.24 ();
@@ -118,9 +113,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -128,7 +124,7 @@ Dist::Metadata::Dir - Enable Dist::Metadata for a directory
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
