@@ -10,14 +10,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Dist;
-{
-  $Dist::Metadata::Dist::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Dist::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Base class for format-specific implementations
-
+$Dist::Metadata::Dist::VERSION = '0.926';
 use Carp qw(croak carp);     # core
 use CPAN::DistnameInfo 0.12 ();
 use Path::Class 0.24 ();
@@ -365,9 +360,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -375,7 +371,7 @@ Dist::Metadata::Dist - Base class for format-specific implementations
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
@@ -494,7 +490,7 @@ Returns a list of the files in the dist starting at the dist root.
 
 This calls L</find_files> to get a listing of the contents of the dist,
 determines (and caches) the root directory (if any),
-caches and returns the the list of files with the root dir stripped.
+caches and returns the list of files with the root dir stripped.
 
   @files = $dist->list_files;
   # something like qw( README META.yml lib/Mod.pm )
