@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Struct;
-{
-  $Dist::Metadata::Struct::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Struct::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Enable Dist::Metadata for a data structure
-
+$Dist::Metadata::Struct::VERSION = '0.926';
 use Carp qw(croak carp); # core
 use parent 'Dist::Metadata::Dist';
 
@@ -63,9 +58,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -73,7 +69,7 @@ Dist::Metadata::Struct - Enable Dist::Metadata for a data structure
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
