@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Tar;
-{
-  $Dist::Metadata::Tar::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Tar::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Enable Dist::Metadata for tar files
-
+$Dist::Metadata::Tar::VERSION = '0.926';
 use Archive::Tar 1 ();   # 0.07 isn't good enough
 use Carp (); # core
 use parent 'Dist::Metadata::Archive';
@@ -58,9 +53,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -68,7 +64,7 @@ Dist::Metadata::Tar - Enable Dist::Metadata for tar files
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
