@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Metadata::Zip;
-{
-  $Dist::Metadata::Zip::VERSION = '0.925';
-}
-BEGIN {
-  $Dist::Metadata::Zip::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Enable Dist::Metadata for zip files
-
+$Dist::Metadata::Zip::VERSION = '0.926';
 use Archive::Zip 1.30 ();
 use Carp (); # core
 
@@ -58,9 +53,10 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS TODO dist dists dir unix checksum checksums
+David Jeffrey Ryan Sawyer Steinbrunner Thalhammer X
 
 =head1 NAME
 
@@ -68,7 +64,7 @@ Dist::Metadata::Zip - Enable Dist::Metadata for zip files
 
 =head1 VERSION
 
-version 0.925
+version 0.926
 
 =head1 SYNOPSIS
 
